@@ -15,28 +15,27 @@
 //
 package org.msgpack.core.example
 
-import org.msgpack.core.MessagePackSpec
+import wvlet.airspec.AirSpec
 
 /**
-  *
   */
-class MessagePackExampleTest extends MessagePackSpec {
+class MessagePackExampleTest extends AirSpec {
 
-  "example" should {
+  test("example") {
 
-    "have basic usage" in {
+    test("have basic usage") {
       MessagePackExample.basicUsage()
     }
 
-    "have packer usage" in {
+    test("have packer usage") {
       MessagePackExample.packer()
     }
 
-    "have file read/write example" in {
+    test("have file read/write example") {
       MessagePackExample.readAndWriteFile();
     }
 
-    "have configuration example" in {
+    test("have configuration example") {
       MessagePackExample.configuration();
     }
   }
