@@ -15,9 +15,12 @@
 //
 package org.msgpack.jackson.dataformat;
 
+import com.fasterxml.jackson.annotation.JsonFormat;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.cfg.MapperBuilder;
 
+import java.math.BigDecimal;
+
 public class MessagePackMapper extends ObjectMapper
 {
     private static final long serialVersionUID = 3L;
@@ -40,6 +43,12 @@ public class MessagePackMapper extends ObjectMapper
         super(f);
     }
 
+    public MessagePackMapper handleBigDecimalAsString()
+    {
+        configOverride(BigDecimal.class).setFormat(JsonFormat.Value.forShape(JsonFormat.Shape.STRING));
+        return this;
+    }
+
     public static Builder builder()
     {
         return new Builder(new MessagePackMapper());
